| Title: | Read Mahjong Logs From 'tenhou.net/6' Format |
|---|---|
| Description: | Offers wrappers for the 'convlog' crate from 'mjai-reviewer' <https://github.com/Equim-chan/mjai-reviewer> that can directly read mahjong logs from 'tenhou.net/6' format into tibbles. |
| Authors: | Akiru Kato [aut, cre], Equim-chan [cph] (Author of the 'convlog' crate) |
| Maintainer: | Akiru Kato <[email protected]> |
| License: | Apache License (>= 2) |
| Version: | 0.0.10 |
| Built: | 2026-06-02 15:09:39 UTC |
| Source: | https://github.com/paithiov909/convlog |
Reads and parses 'tenhou.net/6' format JSON files while transforming them into 'mjai' format.
read_tenhou6(file, .progress = FALSE) read_mjlog(file, .progress = FALSE)read_tenhou6(file, .progress = FALSE) read_mjlog(file, .progress = FALSE)
file |
A character vector.
This argument is simply passed to |
.progress |
Whether to show progress bar for |
Alternatively, read_mjlog() can directly read local 'MJLOG' XML files
while converting them into 'mjai' format.
This function returns almost the same result as read_tenhou6(),
but they are not exactly the same.
As far as I have noticed, the differences are:
tehais in game_info are not arranged.
reach_accepted events are always inserted
immediately after the reach event in this implementation,
even when the reach indicator was melded by another player.
Due to this, numbering style of round_id is also different
than in read_tenhou6().
tsumogiri detection is much stricter than in read_tenhou6().
Even after melds, if the discard is the same as the previous draw,
it is considered a tsumogiri.
ura_markers are not revealed when there is no "doraHaiUra" attribute.
A named list that contains following elements:
game_info: A tibble that contains information about the games.
round_info: A tibble that contains information about rounds.
paifu: A tibble that represents paifu.